/************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 * 
 * Copyright 2008, 2010 Oracle and/or its affiliates. All rights reserved.
 * 
 * Use is subject to license terms.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0. You can also
 * obtain a copy of the License at http://odftoolkit.org/docs/license.txt
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * 
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************************/
// !!! GENERATED SOURCE CODE !!!
package org.odftoolkit.odfdom.dom.style;

import org.odftoolkit.odfdom.dom.attribute.style.StyleFamilyAttribute;
import org.odftoolkit.odfdom.dom.element.style.StyleChartPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleDrawingPagePropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleGraphicPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleListLevelPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleParagraphPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleRubyPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleSectionPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleTableCellPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleTableColumnPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleTablePropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleTableRowPropertiesElement;
import org.odftoolkit.odfdom.dom.element.style.StyleTextPropertiesElement;
import org.odftoolkit.odfdom.dom.style.props.OdfStyleProperty;

import java.util.Set;
import java.util.TreeSet;
import java.util.Map;
import java.util.HashMap;

public class OdfStyleFamily implements Comparable<OdfStyleFamily> {

    private String m_name;
//    private Class m_styleClass;
    private Set<OdfStyleProperty> m_properties = new TreeSet<OdfStyleProperty>();
    private static Map<String, OdfStyleFamily> m_familyByName = new HashMap<String, OdfStyleFamily>();

    public static OdfStyleFamily getByName(String name) {
        return m_familyByName.get(name);
    }

    private OdfStyleFamily(String name /*, Class styleClass*/, OdfStyleProperty[] props) {
        m_name = name;
//        m_styleClass = styleClass;
        for (OdfStyleProperty prop : props) {
            m_properties.add(prop);
        }
        m_familyByName.put(name, this);
    }

    public String getName() {
        return m_name;
    }

    public int compareTo(OdfStyleFamily o) {
        return m_name.compareTo(o.toString());
    }  

    public static OdfStyleFamily valueOf( String name )
    {
        OdfStyleFamily family = getByName(name);
        if( family == null )
            family = new OdfStyleFamily(name,  new OdfStyleProperty[]{ null } );
        
        return family;
    }
    
    public static String toString( OdfStyleFamily family )
    {
        if( family != null )
            return family.toString();
        else
            return new String();
    }
    
    @Override
    public String toString() {
        return m_name;
    }

    public Set<OdfStyleProperty> getProperties() {
        return m_properties;
    }

    public final static OdfStyleFamily Text = new OdfStyleFamily("text",
//            OdfTextStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode
    ,
             });
    public final static OdfStyleFamily Paragraph = new OdfStyleFamily("paragraph",
//            OdfParagraphStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode,
        StyleParagraphPropertiesElement.BackgroundColor,
        StyleParagraphPropertiesElement.Border,
        StyleParagraphPropertiesElement.BorderBottom,
        StyleParagraphPropertiesElement.BorderLeft,
        StyleParagraphPropertiesElement.BorderRight,
        StyleParagraphPropertiesElement.BorderTop,
        StyleParagraphPropertiesElement.BreakAfter,
        StyleParagraphPropertiesElement.BreakBefore,
        StyleParagraphPropertiesElement.HyphenationKeep,
        StyleParagraphPropertiesElement.HyphenationLadderCount,
        StyleParagraphPropertiesElement.JoinBorder,
        StyleParagraphPropertiesElement.KeepTogether,
        StyleParagraphPropertiesElement.KeepWithNext,
        StyleParagraphPropertiesElement.LineHeight,
        StyleParagraphPropertiesElement.Margin,
        StyleParagraphPropertiesElement.MarginBottom,
        StyleParagraphPropertiesElement.MarginLeft,
        StyleParagraphPropertiesElement.MarginRight,
        StyleParagraphPropertiesElement.MarginTop,
        StyleParagraphPropertiesElement.Orphans,
        StyleParagraphPropertiesElement.Padding,
        StyleParagraphPropertiesElement.PaddingBottom,
        StyleParagraphPropertiesElement.PaddingLeft,
        StyleParagraphPropertiesElement.PaddingRight,
        StyleParagraphPropertiesElement.PaddingTop,
        StyleParagraphPropertiesElement.TextAlign,
        StyleParagraphPropertiesElement.TextAlignLast,
        StyleParagraphPropertiesElement.TextIndent,
        StyleParagraphPropertiesElement.Widows,
        StyleParagraphPropertiesElement.AutoTextIndent,
        StyleParagraphPropertiesElement.BackgroundTransparency,
        StyleParagraphPropertiesElement.BorderLineWidth,
        StyleParagraphPropertiesElement.BorderLineWidthBottom,
        StyleParagraphPropertiesElement.BorderLineWidthLeft,
        StyleParagraphPropertiesElement.BorderLineWidthRight,
        StyleParagraphPropertiesElement.BorderLineWidthTop,
        StyleParagraphPropertiesElement.FontIndependentLineSpacing,
        StyleParagraphPropertiesElement.JustifySingleWord,
        StyleParagraphPropertiesElement.LineBreak,
        StyleParagraphPropertiesElement.LineHeightAtLeast,
        StyleParagraphPropertiesElement.LineSpacing,
        StyleParagraphPropertiesElement.PageNumber,
        StyleParagraphPropertiesElement.PunctuationWrap,
        StyleParagraphPropertiesElement.RegisterTrue,
        StyleParagraphPropertiesElement.Shadow,
        StyleParagraphPropertiesElement.SnapToLayoutGrid,
        StyleParagraphPropertiesElement.TabStopDistance,
        StyleParagraphPropertiesElement.TextAutospace,
        StyleParagraphPropertiesElement.VerticalAlign,
        StyleParagraphPropertiesElement.WritingMode,
        StyleParagraphPropertiesElement.WritingModeAutomatic,
        StyleParagraphPropertiesElement.LineNumber,
        StyleParagraphPropertiesElement.NumberLines
    ,
             });
    public final static OdfStyleFamily Section = new OdfStyleFamily("section",
//            OdfSectionStyle.class,
            new OdfStyleProperty[]{
        StyleSectionPropertiesElement.BackgroundColor,
        StyleSectionPropertiesElement.MarginLeft,
        StyleSectionPropertiesElement.MarginRight,
        StyleSectionPropertiesElement.Protect,
        StyleSectionPropertiesElement.WritingMode,
        StyleSectionPropertiesElement.DontBalanceTextColumns,
        StyleSectionPropertiesElement.Editable
    ,
             });
    public final static OdfStyleFamily Ruby = new OdfStyleFamily("ruby",
//            OdfRubyStyle.class,
            new OdfStyleProperty[]{
        StyleRubyPropertiesElement.RubyAlign,
        StyleRubyPropertiesElement.RubyPosition
    ,
             });
    public final static OdfStyleFamily Table = new OdfStyleFamily("table",
//            OdfTableStyle.class,
            new OdfStyleProperty[]{
        StyleTablePropertiesElement.BackgroundColor,
        StyleTablePropertiesElement.BreakAfter,
        StyleTablePropertiesElement.BreakBefore,
        StyleTablePropertiesElement.KeepWithNext,
        StyleTablePropertiesElement.Margin,
        StyleTablePropertiesElement.MarginBottom,
        StyleTablePropertiesElement.MarginLeft,
        StyleTablePropertiesElement.MarginRight,
        StyleTablePropertiesElement.MarginTop,
        StyleTablePropertiesElement.MayBreakBetweenRows,
        StyleTablePropertiesElement.PageNumber,
        StyleTablePropertiesElement.RelWidth,
        StyleTablePropertiesElement.Shadow,
        StyleTablePropertiesElement.Width,
        StyleTablePropertiesElement.WritingMode,
        StyleTablePropertiesElement.Align,
        StyleTablePropertiesElement.BorderModel,
        StyleTablePropertiesElement.Display
    ,
             });
    public final static OdfStyleFamily TableColumn = new OdfStyleFamily("table-column",
//            OdfTableColumnStyle.class,
            new OdfStyleProperty[]{
        StyleTableColumnPropertiesElement.BreakAfter,
        StyleTableColumnPropertiesElement.BreakBefore,
        StyleTableColumnPropertiesElement.ColumnWidth,
        StyleTableColumnPropertiesElement.RelColumnWidth,
        StyleTableColumnPropertiesElement.UseOptimalColumnWidth
    ,
             });
    public final static OdfStyleFamily TableRow = new OdfStyleFamily("table-row",
//            OdfTableRowStyle.class,
            new OdfStyleProperty[]{
        StyleTableRowPropertiesElement.BackgroundColor,
        StyleTableRowPropertiesElement.BreakAfter,
        StyleTableRowPropertiesElement.BreakBefore,
        StyleTableRowPropertiesElement.KeepTogether,
        StyleTableRowPropertiesElement.MinRowHeight,
        StyleTableRowPropertiesElement.RowHeight,
        StyleTableRowPropertiesElement.UseOptimalRowHeight
    ,
             });
    public final static OdfStyleFamily TableCell = new OdfStyleFamily("table-cell",
//            OdfTableCellStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode,
        StyleParagraphPropertiesElement.BackgroundColor,
        StyleParagraphPropertiesElement.Border,
        StyleParagraphPropertiesElement.BorderBottom,
        StyleParagraphPropertiesElement.BorderLeft,
        StyleParagraphPropertiesElement.BorderRight,
        StyleParagraphPropertiesElement.BorderTop,
        StyleParagraphPropertiesElement.BreakAfter,
        StyleParagraphPropertiesElement.BreakBefore,
        StyleParagraphPropertiesElement.HyphenationKeep,
        StyleParagraphPropertiesElement.HyphenationLadderCount,
        StyleParagraphPropertiesElement.JoinBorder,
        StyleParagraphPropertiesElement.KeepTogether,
        StyleParagraphPropertiesElement.KeepWithNext,
        StyleParagraphPropertiesElement.LineHeight,
        StyleParagraphPropertiesElement.Margin,
        StyleParagraphPropertiesElement.MarginBottom,
        StyleParagraphPropertiesElement.MarginLeft,
        StyleParagraphPropertiesElement.MarginRight,
        StyleParagraphPropertiesElement.MarginTop,
        StyleParagraphPropertiesElement.Orphans,
        StyleParagraphPropertiesElement.Padding,
        StyleParagraphPropertiesElement.PaddingBottom,
        StyleParagraphPropertiesElement.PaddingLeft,
        StyleParagraphPropertiesElement.PaddingRight,
        StyleParagraphPropertiesElement.PaddingTop,
        StyleParagraphPropertiesElement.TextAlign,
        StyleParagraphPropertiesElement.TextAlignLast,
        StyleParagraphPropertiesElement.TextIndent,
        StyleParagraphPropertiesElement.Widows,
        StyleParagraphPropertiesElement.AutoTextIndent,
        StyleParagraphPropertiesElement.BackgroundTransparency,
        StyleParagraphPropertiesElement.BorderLineWidth,
        StyleParagraphPropertiesElement.BorderLineWidthBottom,
        StyleParagraphPropertiesElement.BorderLineWidthLeft,
        StyleParagraphPropertiesElement.BorderLineWidthRight,
        StyleParagraphPropertiesElement.BorderLineWidthTop,
        StyleParagraphPropertiesElement.FontIndependentLineSpacing,
        StyleParagraphPropertiesElement.JustifySingleWord,
        StyleParagraphPropertiesElement.LineBreak,
        StyleParagraphPropertiesElement.LineHeightAtLeast,
        StyleParagraphPropertiesElement.LineSpacing,
        StyleParagraphPropertiesElement.PageNumber,
        StyleParagraphPropertiesElement.PunctuationWrap,
        StyleParagraphPropertiesElement.RegisterTrue,
        StyleParagraphPropertiesElement.Shadow,
        StyleParagraphPropertiesElement.SnapToLayoutGrid,
        StyleParagraphPropertiesElement.TabStopDistance,
        StyleParagraphPropertiesElement.TextAutospace,
        StyleParagraphPropertiesElement.VerticalAlign,
        StyleParagraphPropertiesElement.WritingMode,
        StyleParagraphPropertiesElement.WritingModeAutomatic,
        StyleParagraphPropertiesElement.LineNumber,
        StyleParagraphPropertiesElement.NumberLines,
        StyleTableCellPropertiesElement.BackgroundColor,
        StyleTableCellPropertiesElement.Border,
        StyleTableCellPropertiesElement.BorderBottom,
        StyleTableCellPropertiesElement.BorderLeft,
        StyleTableCellPropertiesElement.BorderRight,
        StyleTableCellPropertiesElement.BorderTop,
        StyleTableCellPropertiesElement.Padding,
        StyleTableCellPropertiesElement.PaddingBottom,
        StyleTableCellPropertiesElement.PaddingLeft,
        StyleTableCellPropertiesElement.PaddingRight,
        StyleTableCellPropertiesElement.PaddingTop,
        StyleTableCellPropertiesElement.WrapOption,
        StyleTableCellPropertiesElement.BorderLineWidth,
        StyleTableCellPropertiesElement.BorderLineWidthBottom,
        StyleTableCellPropertiesElement.BorderLineWidthLeft,
        StyleTableCellPropertiesElement.BorderLineWidthRight,
        StyleTableCellPropertiesElement.BorderLineWidthTop,
        StyleTableCellPropertiesElement.CellProtect,
        StyleTableCellPropertiesElement.DecimalPlaces,
        StyleTableCellPropertiesElement.DiagonalBlTr,
        StyleTableCellPropertiesElement.DiagonalBlTrWidths,
        StyleTableCellPropertiesElement.DiagonalTlBr,
        StyleTableCellPropertiesElement.DiagonalTlBrWidths,
        StyleTableCellPropertiesElement.Direction,
        StyleTableCellPropertiesElement.GlyphOrientationVertical,
        StyleTableCellPropertiesElement.PrintContent,
        StyleTableCellPropertiesElement.RepeatContent,
        StyleTableCellPropertiesElement.RotationAlign,
        StyleTableCellPropertiesElement.RotationAngle,
        StyleTableCellPropertiesElement.Shadow,
        StyleTableCellPropertiesElement.ShrinkToFit,
        StyleTableCellPropertiesElement.TextAlignSource,
        StyleTableCellPropertiesElement.VerticalAlign,
        StyleTableCellPropertiesElement.WritingMode
    ,
             });
    public final static OdfStyleFamily Graphic = new OdfStyleFamily("graphic",
//            OdfGraphicStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode,
        StyleParagraphPropertiesElement.BackgroundColor,
        StyleParagraphPropertiesElement.Border,
        StyleParagraphPropertiesElement.BorderBottom,
        StyleParagraphPropertiesElement.BorderLeft,
        StyleParagraphPropertiesElement.BorderRight,
        StyleParagraphPropertiesElement.BorderTop,
        StyleParagraphPropertiesElement.BreakAfter,
        StyleParagraphPropertiesElement.BreakBefore,
        StyleParagraphPropertiesElement.HyphenationKeep,
        StyleParagraphPropertiesElement.HyphenationLadderCount,
        StyleParagraphPropertiesElement.JoinBorder,
        StyleParagraphPropertiesElement.KeepTogether,
        StyleParagraphPropertiesElement.KeepWithNext,
        StyleParagraphPropertiesElement.LineHeight,
        StyleParagraphPropertiesElement.Margin,
        StyleParagraphPropertiesElement.MarginBottom,
        StyleParagraphPropertiesElement.MarginLeft,
        StyleParagraphPropertiesElement.MarginRight,
        StyleParagraphPropertiesElement.MarginTop,
        StyleParagraphPropertiesElement.Orphans,
        StyleParagraphPropertiesElement.Padding,
        StyleParagraphPropertiesElement.PaddingBottom,
        StyleParagraphPropertiesElement.PaddingLeft,
        StyleParagraphPropertiesElement.PaddingRight,
        StyleParagraphPropertiesElement.PaddingTop,
        StyleParagraphPropertiesElement.TextAlign,
        StyleParagraphPropertiesElement.TextAlignLast,
        StyleParagraphPropertiesElement.TextIndent,
        StyleParagraphPropertiesElement.Widows,
        StyleParagraphPropertiesElement.AutoTextIndent,
        StyleParagraphPropertiesElement.BackgroundTransparency,
        StyleParagraphPropertiesElement.BorderLineWidth,
        StyleParagraphPropertiesElement.BorderLineWidthBottom,
        StyleParagraphPropertiesElement.BorderLineWidthLeft,
        StyleParagraphPropertiesElement.BorderLineWidthRight,
        StyleParagraphPropertiesElement.BorderLineWidthTop,
        StyleParagraphPropertiesElement.FontIndependentLineSpacing,
        StyleParagraphPropertiesElement.JustifySingleWord,
        StyleParagraphPropertiesElement.LineBreak,
        StyleParagraphPropertiesElement.LineHeightAtLeast,
        StyleParagraphPropertiesElement.LineSpacing,
        StyleParagraphPropertiesElement.PageNumber,
        StyleParagraphPropertiesElement.PunctuationWrap,
        StyleParagraphPropertiesElement.RegisterTrue,
        StyleParagraphPropertiesElement.Shadow,
        StyleParagraphPropertiesElement.SnapToLayoutGrid,
        StyleParagraphPropertiesElement.TabStopDistance,
        StyleParagraphPropertiesElement.TextAutospace,
        StyleParagraphPropertiesElement.VerticalAlign,
        StyleParagraphPropertiesElement.WritingMode,
        StyleParagraphPropertiesElement.WritingModeAutomatic,
        StyleParagraphPropertiesElement.LineNumber,
        StyleParagraphPropertiesElement.NumberLines,
        StyleGraphicPropertiesElement.AmbientColor,
        StyleGraphicPropertiesElement.BackScale,
        StyleGraphicPropertiesElement.BackfaceCulling,
        StyleGraphicPropertiesElement.CloseBack,
        StyleGraphicPropertiesElement.CloseFront,
        StyleGraphicPropertiesElement.Depth,
        StyleGraphicPropertiesElement.DiffuseColor,
        StyleGraphicPropertiesElement.EdgeRounding,
        StyleGraphicPropertiesElement.EdgeRoundingMode,
        StyleGraphicPropertiesElement.EmissiveColor,
        StyleGraphicPropertiesElement.EndAngle,
        StyleGraphicPropertiesElement.HorizontalSegments,
        StyleGraphicPropertiesElement.LightingMode,
        StyleGraphicPropertiesElement.NormalsDirection,
        StyleGraphicPropertiesElement.NormalsKind,
        StyleGraphicPropertiesElement.DrawShadow,
        StyleGraphicPropertiesElement.Dr3dShadow,
        StyleGraphicPropertiesElement.Shininess,
        StyleGraphicPropertiesElement.SpecularColor,
        StyleGraphicPropertiesElement.TextureFilter,
        StyleGraphicPropertiesElement.TextureGenerationModeX,
        StyleGraphicPropertiesElement.TextureGenerationModeY,
        StyleGraphicPropertiesElement.TextureKind,
        StyleGraphicPropertiesElement.TextureMode,
        StyleGraphicPropertiesElement.VerticalSegments,
        StyleGraphicPropertiesElement.AutoGrowHeight,
        StyleGraphicPropertiesElement.AutoGrowWidth,
        StyleGraphicPropertiesElement.Blue,
        StyleGraphicPropertiesElement.CaptionAngle,
        StyleGraphicPropertiesElement.CaptionAngleType,
        StyleGraphicPropertiesElement.CaptionEscape,
        StyleGraphicPropertiesElement.CaptionEscapeDirection,
        StyleGraphicPropertiesElement.CaptionFitLineLength,
        StyleGraphicPropertiesElement.CaptionGap,
        StyleGraphicPropertiesElement.CaptionLineLength,
        StyleGraphicPropertiesElement.CaptionType,
        StyleGraphicPropertiesElement.ColorInversion,
        StyleGraphicPropertiesElement.ColorMode,
        StyleGraphicPropertiesElement.Contrast,
        StyleGraphicPropertiesElement.DecimalPlaces,
        StyleGraphicPropertiesElement.EndGuide,
        StyleGraphicPropertiesElement.EndLineSpacingHorizontal,
        StyleGraphicPropertiesElement.EndLineSpacingVertical,
        StyleGraphicPropertiesElement.FitToContour,
        StyleGraphicPropertiesElement.FitToSize,
        StyleGraphicPropertiesElement.FrameDisplayBorder,
        StyleGraphicPropertiesElement.FrameDisplayScrollbar,
        StyleGraphicPropertiesElement.FrameMarginHorizontal,
        StyleGraphicPropertiesElement.FrameMarginVertical,
        StyleGraphicPropertiesElement.Gamma,
        StyleGraphicPropertiesElement.Green,
        StyleGraphicPropertiesElement.GuideDistance,
        StyleGraphicPropertiesElement.GuideOverhang,
        StyleGraphicPropertiesElement.ImageOpacity,
        StyleGraphicPropertiesElement.LineDistance,
        StyleGraphicPropertiesElement.Luminance,
        StyleGraphicPropertiesElement.MarkerEnd,
        StyleGraphicPropertiesElement.MarkerEndCenter,
        StyleGraphicPropertiesElement.MarkerEndWidth,
        StyleGraphicPropertiesElement.MarkerStart,
        StyleGraphicPropertiesElement.MarkerStartCenter,
        StyleGraphicPropertiesElement.MarkerStartWidth,
        StyleGraphicPropertiesElement.MeasureAlign,
        StyleGraphicPropertiesElement.MeasureVerticalAlign,
        StyleGraphicPropertiesElement.OleDrawAspect,
        StyleGraphicPropertiesElement.Parallel,
        StyleGraphicPropertiesElement.Placing,
        StyleGraphicPropertiesElement.Red,
        StyleGraphicPropertiesElement.ShadowColor,
        StyleGraphicPropertiesElement.ShadowOffsetX,
        StyleGraphicPropertiesElement.ShadowOffsetY,
        StyleGraphicPropertiesElement.ShadowOpacity,
        StyleGraphicPropertiesElement.ShowUnit,
        StyleGraphicPropertiesElement.StartGuide,
        StyleGraphicPropertiesElement.StartLineSpacingHorizontal,
        StyleGraphicPropertiesElement.StartLineSpacingVertical,
        StyleGraphicPropertiesElement.Stroke,
        StyleGraphicPropertiesElement.StrokeDash,
        StyleGraphicPropertiesElement.StrokeDashNames,
        StyleGraphicPropertiesElement.StrokeLinejoin,
        StyleGraphicPropertiesElement.SymbolColor,
        StyleGraphicPropertiesElement.TextareaHorizontalAlign,
        StyleGraphicPropertiesElement.TextareaVerticalAlign,
        StyleGraphicPropertiesElement.Unit,
        StyleGraphicPropertiesElement.VisibleAreaHeight,
        StyleGraphicPropertiesElement.VisibleAreaLeft,
        StyleGraphicPropertiesElement.VisibleAreaTop,
        StyleGraphicPropertiesElement.VisibleAreaWidth,
        StyleGraphicPropertiesElement.WrapInfluenceOnPosition,
        StyleGraphicPropertiesElement.BackgroundColor,
        StyleGraphicPropertiesElement.Border,
        StyleGraphicPropertiesElement.BorderBottom,
        StyleGraphicPropertiesElement.BorderLeft,
        StyleGraphicPropertiesElement.BorderRight,
        StyleGraphicPropertiesElement.BorderTop,
        StyleGraphicPropertiesElement.Clip,
        StyleGraphicPropertiesElement.Margin,
        StyleGraphicPropertiesElement.MarginBottom,
        StyleGraphicPropertiesElement.MarginLeft,
        StyleGraphicPropertiesElement.MarginRight,
        StyleGraphicPropertiesElement.MarginTop,
        StyleGraphicPropertiesElement.MaxHeight,
        StyleGraphicPropertiesElement.MaxWidth,
        StyleGraphicPropertiesElement.MinHeight,
        StyleGraphicPropertiesElement.MinWidth,
        StyleGraphicPropertiesElement.Padding,
        StyleGraphicPropertiesElement.PaddingBottom,
        StyleGraphicPropertiesElement.PaddingLeft,
        StyleGraphicPropertiesElement.PaddingRight,
        StyleGraphicPropertiesElement.PaddingTop,
        StyleGraphicPropertiesElement.WrapOption,
        StyleGraphicPropertiesElement.BorderLineWidth,
        StyleGraphicPropertiesElement.BorderLineWidthBottom,
        StyleGraphicPropertiesElement.BorderLineWidthLeft,
        StyleGraphicPropertiesElement.BorderLineWidthRight,
        StyleGraphicPropertiesElement.BorderLineWidthTop,
        StyleGraphicPropertiesElement.Editable,
        StyleGraphicPropertiesElement.FlowWithText,
        StyleGraphicPropertiesElement.HorizontalPos,
        StyleGraphicPropertiesElement.HorizontalRel,
        StyleGraphicPropertiesElement.Mirror,
        StyleGraphicPropertiesElement.NumberWrappedParagraphs,
        StyleGraphicPropertiesElement.OverflowBehavior,
        StyleGraphicPropertiesElement.PrintContent,
        StyleGraphicPropertiesElement.Protect,
        StyleGraphicPropertiesElement.RelHeight,
        StyleGraphicPropertiesElement.RelWidth,
        StyleGraphicPropertiesElement.RunThrough,
        StyleGraphicPropertiesElement.Shadow,
        StyleGraphicPropertiesElement.VerticalPos,
        StyleGraphicPropertiesElement.VerticalRel,
        StyleGraphicPropertiesElement.Wrap,
        StyleGraphicPropertiesElement.WrapContour,
        StyleGraphicPropertiesElement.WrapContourMode,
        StyleGraphicPropertiesElement.WrapDynamicThreshold,
        StyleGraphicPropertiesElement.WritingMode,
        StyleGraphicPropertiesElement.Height,
        StyleGraphicPropertiesElement.StrokeColor,
        StyleGraphicPropertiesElement.StrokeOpacity,
        StyleGraphicPropertiesElement.StrokeWidth,
        StyleGraphicPropertiesElement.Width,
        StyleGraphicPropertiesElement.X,
        StyleGraphicPropertiesElement.Y,
        StyleGraphicPropertiesElement.AnchorPageNumber,
        StyleGraphicPropertiesElement.AnchorType,
        StyleGraphicPropertiesElement.Animation,
        StyleGraphicPropertiesElement.AnimationDelay,
        StyleGraphicPropertiesElement.AnimationDirection,
        StyleGraphicPropertiesElement.AnimationRepeat,
        StyleGraphicPropertiesElement.AnimationStartInside,
        StyleGraphicPropertiesElement.AnimationSteps,
        StyleGraphicPropertiesElement.AnimationStopInside,
        StyleGraphicPropertiesElement.StrokeLinecap,
        StyleGraphicPropertiesElement.ShrinkToFit,
        StyleGraphicPropertiesElement.BackgroundTransparency,
        StyleGraphicPropertiesElement.DrawAspect
    ,
             });
    public final static OdfStyleFamily Presentation = new OdfStyleFamily("presentation",
//            OdfPresentationStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode,
        StyleParagraphPropertiesElement.BackgroundColor,
        StyleParagraphPropertiesElement.Border,
        StyleParagraphPropertiesElement.BorderBottom,
        StyleParagraphPropertiesElement.BorderLeft,
        StyleParagraphPropertiesElement.BorderRight,
        StyleParagraphPropertiesElement.BorderTop,
        StyleParagraphPropertiesElement.BreakAfter,
        StyleParagraphPropertiesElement.BreakBefore,
        StyleParagraphPropertiesElement.HyphenationKeep,
        StyleParagraphPropertiesElement.HyphenationLadderCount,
        StyleParagraphPropertiesElement.JoinBorder,
        StyleParagraphPropertiesElement.KeepTogether,
        StyleParagraphPropertiesElement.KeepWithNext,
        StyleParagraphPropertiesElement.LineHeight,
        StyleParagraphPropertiesElement.Margin,
        StyleParagraphPropertiesElement.MarginBottom,
        StyleParagraphPropertiesElement.MarginLeft,
        StyleParagraphPropertiesElement.MarginRight,
        StyleParagraphPropertiesElement.MarginTop,
        StyleParagraphPropertiesElement.Orphans,
        StyleParagraphPropertiesElement.Padding,
        StyleParagraphPropertiesElement.PaddingBottom,
        StyleParagraphPropertiesElement.PaddingLeft,
        StyleParagraphPropertiesElement.PaddingRight,
        StyleParagraphPropertiesElement.PaddingTop,
        StyleParagraphPropertiesElement.TextAlign,
        StyleParagraphPropertiesElement.TextAlignLast,
        StyleParagraphPropertiesElement.TextIndent,
        StyleParagraphPropertiesElement.Widows,
        StyleParagraphPropertiesElement.AutoTextIndent,
        StyleParagraphPropertiesElement.BackgroundTransparency,
        StyleParagraphPropertiesElement.BorderLineWidth,
        StyleParagraphPropertiesElement.BorderLineWidthBottom,
        StyleParagraphPropertiesElement.BorderLineWidthLeft,
        StyleParagraphPropertiesElement.BorderLineWidthRight,
        StyleParagraphPropertiesElement.BorderLineWidthTop,
        StyleParagraphPropertiesElement.FontIndependentLineSpacing,
        StyleParagraphPropertiesElement.JustifySingleWord,
        StyleParagraphPropertiesElement.LineBreak,
        StyleParagraphPropertiesElement.LineHeightAtLeast,
        StyleParagraphPropertiesElement.LineSpacing,
        StyleParagraphPropertiesElement.PageNumber,
        StyleParagraphPropertiesElement.PunctuationWrap,
        StyleParagraphPropertiesElement.RegisterTrue,
        StyleParagraphPropertiesElement.Shadow,
        StyleParagraphPropertiesElement.SnapToLayoutGrid,
        StyleParagraphPropertiesElement.TabStopDistance,
        StyleParagraphPropertiesElement.TextAutospace,
        StyleParagraphPropertiesElement.VerticalAlign,
        StyleParagraphPropertiesElement.WritingMode,
        StyleParagraphPropertiesElement.WritingModeAutomatic,
        StyleParagraphPropertiesElement.LineNumber,
        StyleParagraphPropertiesElement.NumberLines,
        StyleGraphicPropertiesElement.AmbientColor,
        StyleGraphicPropertiesElement.BackScale,
        StyleGraphicPropertiesElement.BackfaceCulling,
        StyleGraphicPropertiesElement.CloseBack,
        StyleGraphicPropertiesElement.CloseFront,
        StyleGraphicPropertiesElement.Depth,
        StyleGraphicPropertiesElement.DiffuseColor,
        StyleGraphicPropertiesElement.EdgeRounding,
        StyleGraphicPropertiesElement.EdgeRoundingMode,
        StyleGraphicPropertiesElement.EmissiveColor,
        StyleGraphicPropertiesElement.EndAngle,
        StyleGraphicPropertiesElement.HorizontalSegments,
        StyleGraphicPropertiesElement.LightingMode,
        StyleGraphicPropertiesElement.NormalsDirection,
        StyleGraphicPropertiesElement.NormalsKind,
        StyleGraphicPropertiesElement.DrawShadow,
        StyleGraphicPropertiesElement.Dr3dShadow,
        StyleGraphicPropertiesElement.Shininess,
        StyleGraphicPropertiesElement.SpecularColor,
        StyleGraphicPropertiesElement.TextureFilter,
        StyleGraphicPropertiesElement.TextureGenerationModeX,
        StyleGraphicPropertiesElement.TextureGenerationModeY,
        StyleGraphicPropertiesElement.TextureKind,
        StyleGraphicPropertiesElement.TextureMode,
        StyleGraphicPropertiesElement.VerticalSegments,
        StyleGraphicPropertiesElement.AutoGrowHeight,
        StyleGraphicPropertiesElement.AutoGrowWidth,
        StyleGraphicPropertiesElement.Blue,
        StyleGraphicPropertiesElement.CaptionAngle,
        StyleGraphicPropertiesElement.CaptionAngleType,
        StyleGraphicPropertiesElement.CaptionEscape,
        StyleGraphicPropertiesElement.CaptionEscapeDirection,
        StyleGraphicPropertiesElement.CaptionFitLineLength,
        StyleGraphicPropertiesElement.CaptionGap,
        StyleGraphicPropertiesElement.CaptionLineLength,
        StyleGraphicPropertiesElement.CaptionType,
        StyleGraphicPropertiesElement.ColorInversion,
        StyleGraphicPropertiesElement.ColorMode,
        StyleGraphicPropertiesElement.Contrast,
        StyleGraphicPropertiesElement.DecimalPlaces,
        StyleGraphicPropertiesElement.EndGuide,
        StyleGraphicPropertiesElement.EndLineSpacingHorizontal,
        StyleGraphicPropertiesElement.EndLineSpacingVertical,
        StyleGraphicPropertiesElement.FitToContour,
        StyleGraphicPropertiesElement.FitToSize,
        StyleGraphicPropertiesElement.FrameDisplayBorder,
        StyleGraphicPropertiesElement.FrameDisplayScrollbar,
        StyleGraphicPropertiesElement.FrameMarginHorizontal,
        StyleGraphicPropertiesElement.FrameMarginVertical,
        StyleGraphicPropertiesElement.Gamma,
        StyleGraphicPropertiesElement.Green,
        StyleGraphicPropertiesElement.GuideDistance,
        StyleGraphicPropertiesElement.GuideOverhang,
        StyleGraphicPropertiesElement.ImageOpacity,
        StyleGraphicPropertiesElement.LineDistance,
        StyleGraphicPropertiesElement.Luminance,
        StyleGraphicPropertiesElement.MarkerEnd,
        StyleGraphicPropertiesElement.MarkerEndCenter,
        StyleGraphicPropertiesElement.MarkerEndWidth,
        StyleGraphicPropertiesElement.MarkerStart,
        StyleGraphicPropertiesElement.MarkerStartCenter,
        StyleGraphicPropertiesElement.MarkerStartWidth,
        StyleGraphicPropertiesElement.MeasureAlign,
        StyleGraphicPropertiesElement.MeasureVerticalAlign,
        StyleGraphicPropertiesElement.OleDrawAspect,
        StyleGraphicPropertiesElement.Parallel,
        StyleGraphicPropertiesElement.Placing,
        StyleGraphicPropertiesElement.Red,
        StyleGraphicPropertiesElement.ShadowColor,
        StyleGraphicPropertiesElement.ShadowOffsetX,
        StyleGraphicPropertiesElement.ShadowOffsetY,
        StyleGraphicPropertiesElement.ShadowOpacity,
        StyleGraphicPropertiesElement.ShowUnit,
        StyleGraphicPropertiesElement.StartGuide,
        StyleGraphicPropertiesElement.StartLineSpacingHorizontal,
        StyleGraphicPropertiesElement.StartLineSpacingVertical,
        StyleGraphicPropertiesElement.Stroke,
        StyleGraphicPropertiesElement.StrokeDash,
        StyleGraphicPropertiesElement.StrokeDashNames,
        StyleGraphicPropertiesElement.StrokeLinejoin,
        StyleGraphicPropertiesElement.SymbolColor,
        StyleGraphicPropertiesElement.TextareaHorizontalAlign,
        StyleGraphicPropertiesElement.TextareaVerticalAlign,
        StyleGraphicPropertiesElement.Unit,
        StyleGraphicPropertiesElement.VisibleAreaHeight,
        StyleGraphicPropertiesElement.VisibleAreaLeft,
        StyleGraphicPropertiesElement.VisibleAreaTop,
        StyleGraphicPropertiesElement.VisibleAreaWidth,
        StyleGraphicPropertiesElement.WrapInfluenceOnPosition,
        StyleGraphicPropertiesElement.BackgroundColor,
        StyleGraphicPropertiesElement.Border,
        StyleGraphicPropertiesElement.BorderBottom,
        StyleGraphicPropertiesElement.BorderLeft,
        StyleGraphicPropertiesElement.BorderRight,
        StyleGraphicPropertiesElement.BorderTop,
        StyleGraphicPropertiesElement.Clip,
        StyleGraphicPropertiesElement.Margin,
        StyleGraphicPropertiesElement.MarginBottom,
        StyleGraphicPropertiesElement.MarginLeft,
        StyleGraphicPropertiesElement.MarginRight,
        StyleGraphicPropertiesElement.MarginTop,
        StyleGraphicPropertiesElement.MaxHeight,
        StyleGraphicPropertiesElement.MaxWidth,
        StyleGraphicPropertiesElement.MinHeight,
        StyleGraphicPropertiesElement.MinWidth,
        StyleGraphicPropertiesElement.Padding,
        StyleGraphicPropertiesElement.PaddingBottom,
        StyleGraphicPropertiesElement.PaddingLeft,
        StyleGraphicPropertiesElement.PaddingRight,
        StyleGraphicPropertiesElement.PaddingTop,
        StyleGraphicPropertiesElement.WrapOption,
        StyleGraphicPropertiesElement.BorderLineWidth,
        StyleGraphicPropertiesElement.BorderLineWidthBottom,
        StyleGraphicPropertiesElement.BorderLineWidthLeft,
        StyleGraphicPropertiesElement.BorderLineWidthRight,
        StyleGraphicPropertiesElement.BorderLineWidthTop,
        StyleGraphicPropertiesElement.Editable,
        StyleGraphicPropertiesElement.FlowWithText,
        StyleGraphicPropertiesElement.HorizontalPos,
        StyleGraphicPropertiesElement.HorizontalRel,
        StyleGraphicPropertiesElement.Mirror,
        StyleGraphicPropertiesElement.NumberWrappedParagraphs,
        StyleGraphicPropertiesElement.OverflowBehavior,
        StyleGraphicPropertiesElement.PrintContent,
        StyleGraphicPropertiesElement.Protect,
        StyleGraphicPropertiesElement.RelHeight,
        StyleGraphicPropertiesElement.RelWidth,
        StyleGraphicPropertiesElement.RunThrough,
        StyleGraphicPropertiesElement.Shadow,
        StyleGraphicPropertiesElement.VerticalPos,
        StyleGraphicPropertiesElement.VerticalRel,
        StyleGraphicPropertiesElement.Wrap,
        StyleGraphicPropertiesElement.WrapContour,
        StyleGraphicPropertiesElement.WrapContourMode,
        StyleGraphicPropertiesElement.WrapDynamicThreshold,
        StyleGraphicPropertiesElement.WritingMode,
        StyleGraphicPropertiesElement.Height,
        StyleGraphicPropertiesElement.StrokeColor,
        StyleGraphicPropertiesElement.StrokeOpacity,
        StyleGraphicPropertiesElement.StrokeWidth,
        StyleGraphicPropertiesElement.Width,
        StyleGraphicPropertiesElement.X,
        StyleGraphicPropertiesElement.Y,
        StyleGraphicPropertiesElement.AnchorPageNumber,
        StyleGraphicPropertiesElement.AnchorType,
        StyleGraphicPropertiesElement.Animation,
        StyleGraphicPropertiesElement.AnimationDelay,
        StyleGraphicPropertiesElement.AnimationDirection,
        StyleGraphicPropertiesElement.AnimationRepeat,
        StyleGraphicPropertiesElement.AnimationStartInside,
        StyleGraphicPropertiesElement.AnimationSteps,
        StyleGraphicPropertiesElement.AnimationStopInside,
        StyleGraphicPropertiesElement.StrokeLinecap,
        StyleGraphicPropertiesElement.ShrinkToFit,
        StyleGraphicPropertiesElement.BackgroundTransparency,
        StyleGraphicPropertiesElement.DrawAspect
    ,
             });
    public final static OdfStyleFamily DrawingPage = new OdfStyleFamily("drawing-page",
//            OdfDrawingPageStyle.class,
            new OdfStyleProperty[]{
        StyleDrawingPagePropertiesElement.BackgroundSize,
        StyleDrawingPagePropertiesElement.BackgroundObjectsVisible,
        StyleDrawingPagePropertiesElement.BackgroundVisible,
        StyleDrawingPagePropertiesElement.DisplayDateTime,
        StyleDrawingPagePropertiesElement.DisplayFooter,
        StyleDrawingPagePropertiesElement.DisplayHeader,
        StyleDrawingPagePropertiesElement.DisplayPageNumber,
        StyleDrawingPagePropertiesElement.Duration,
        StyleDrawingPagePropertiesElement.TransitionSpeed,
        StyleDrawingPagePropertiesElement.TransitionStyle,
        StyleDrawingPagePropertiesElement.TransitionType,
        StyleDrawingPagePropertiesElement.Visibility,
        StyleDrawingPagePropertiesElement.Direction,
        StyleDrawingPagePropertiesElement.FadeColor,
        StyleDrawingPagePropertiesElement.Subtype
    ,
             });
    public final static OdfStyleFamily Chart = new OdfStyleFamily("chart",
//            OdfChartStyle.class,
            new OdfStyleProperty[]{
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode,
        StyleParagraphPropertiesElement.BackgroundColor,
        StyleParagraphPropertiesElement.Border,
        StyleParagraphPropertiesElement.BorderBottom,
        StyleParagraphPropertiesElement.BorderLeft,
        StyleParagraphPropertiesElement.BorderRight,
        StyleParagraphPropertiesElement.BorderTop,
        StyleParagraphPropertiesElement.BreakAfter,
        StyleParagraphPropertiesElement.BreakBefore,
        StyleParagraphPropertiesElement.HyphenationKeep,
        StyleParagraphPropertiesElement.HyphenationLadderCount,
        StyleParagraphPropertiesElement.JoinBorder,
        StyleParagraphPropertiesElement.KeepTogether,
        StyleParagraphPropertiesElement.KeepWithNext,
        StyleParagraphPropertiesElement.LineHeight,
        StyleParagraphPropertiesElement.Margin,
        StyleParagraphPropertiesElement.MarginBottom,
        StyleParagraphPropertiesElement.MarginLeft,
        StyleParagraphPropertiesElement.MarginRight,
        StyleParagraphPropertiesElement.MarginTop,
        StyleParagraphPropertiesElement.Orphans,
        StyleParagraphPropertiesElement.Padding,
        StyleParagraphPropertiesElement.PaddingBottom,
        StyleParagraphPropertiesElement.PaddingLeft,
        StyleParagraphPropertiesElement.PaddingRight,
        StyleParagraphPropertiesElement.PaddingTop,
        StyleParagraphPropertiesElement.TextAlign,
        StyleParagraphPropertiesElement.TextAlignLast,
        StyleParagraphPropertiesElement.TextIndent,
        StyleParagraphPropertiesElement.Widows,
        StyleParagraphPropertiesElement.AutoTextIndent,
        StyleParagraphPropertiesElement.BackgroundTransparency,
        StyleParagraphPropertiesElement.BorderLineWidth,
        StyleParagraphPropertiesElement.BorderLineWidthBottom,
        StyleParagraphPropertiesElement.BorderLineWidthLeft,
        StyleParagraphPropertiesElement.BorderLineWidthRight,
        StyleParagraphPropertiesElement.BorderLineWidthTop,
        StyleParagraphPropertiesElement.FontIndependentLineSpacing,
        StyleParagraphPropertiesElement.JustifySingleWord,
        StyleParagraphPropertiesElement.LineBreak,
        StyleParagraphPropertiesElement.LineHeightAtLeast,
        StyleParagraphPropertiesElement.LineSpacing,
        StyleParagraphPropertiesElement.PageNumber,
        StyleParagraphPropertiesElement.PunctuationWrap,
        StyleParagraphPropertiesElement.RegisterTrue,
        StyleParagraphPropertiesElement.Shadow,
        StyleParagraphPropertiesElement.SnapToLayoutGrid,
        StyleParagraphPropertiesElement.TabStopDistance,
        StyleParagraphPropertiesElement.TextAutospace,
        StyleParagraphPropertiesElement.VerticalAlign,
        StyleParagraphPropertiesElement.WritingMode,
        StyleParagraphPropertiesElement.WritingModeAutomatic,
        StyleParagraphPropertiesElement.LineNumber,
        StyleParagraphPropertiesElement.NumberLines,
        StyleGraphicPropertiesElement.AmbientColor,
        StyleGraphicPropertiesElement.BackScale,
        StyleGraphicPropertiesElement.BackfaceCulling,
        StyleGraphicPropertiesElement.CloseBack,
        StyleGraphicPropertiesElement.CloseFront,
        StyleGraphicPropertiesElement.Depth,
        StyleGraphicPropertiesElement.DiffuseColor,
        StyleGraphicPropertiesElement.EdgeRounding,
        StyleGraphicPropertiesElement.EdgeRoundingMode,
        StyleGraphicPropertiesElement.EmissiveColor,
        StyleGraphicPropertiesElement.EndAngle,
        StyleGraphicPropertiesElement.HorizontalSegments,
        StyleGraphicPropertiesElement.LightingMode,
        StyleGraphicPropertiesElement.NormalsDirection,
        StyleGraphicPropertiesElement.NormalsKind,
        StyleGraphicPropertiesElement.DrawShadow,
        StyleGraphicPropertiesElement.Dr3dShadow,
        StyleGraphicPropertiesElement.Shininess,
        StyleGraphicPropertiesElement.SpecularColor,
        StyleGraphicPropertiesElement.TextureFilter,
        StyleGraphicPropertiesElement.TextureGenerationModeX,
        StyleGraphicPropertiesElement.TextureGenerationModeY,
        StyleGraphicPropertiesElement.TextureKind,
        StyleGraphicPropertiesElement.TextureMode,
        StyleGraphicPropertiesElement.VerticalSegments,
        StyleGraphicPropertiesElement.AutoGrowHeight,
        StyleGraphicPropertiesElement.AutoGrowWidth,
        StyleGraphicPropertiesElement.Blue,
        StyleGraphicPropertiesElement.CaptionAngle,
        StyleGraphicPropertiesElement.CaptionAngleType,
        StyleGraphicPropertiesElement.CaptionEscape,
        StyleGraphicPropertiesElement.CaptionEscapeDirection,
        StyleGraphicPropertiesElement.CaptionFitLineLength,
        StyleGraphicPropertiesElement.CaptionGap,
        StyleGraphicPropertiesElement.CaptionLineLength,
        StyleGraphicPropertiesElement.CaptionType,
        StyleGraphicPropertiesElement.ColorInversion,
        StyleGraphicPropertiesElement.ColorMode,
        StyleGraphicPropertiesElement.Contrast,
        StyleGraphicPropertiesElement.DecimalPlaces,
        StyleGraphicPropertiesElement.EndGuide,
        StyleGraphicPropertiesElement.EndLineSpacingHorizontal,
        StyleGraphicPropertiesElement.EndLineSpacingVertical,
        StyleGraphicPropertiesElement.FitToContour,
        StyleGraphicPropertiesElement.FitToSize,
        StyleGraphicPropertiesElement.FrameDisplayBorder,
        StyleGraphicPropertiesElement.FrameDisplayScrollbar,
        StyleGraphicPropertiesElement.FrameMarginHorizontal,
        StyleGraphicPropertiesElement.FrameMarginVertical,
        StyleGraphicPropertiesElement.Gamma,
        StyleGraphicPropertiesElement.Green,
        StyleGraphicPropertiesElement.GuideDistance,
        StyleGraphicPropertiesElement.GuideOverhang,
        StyleGraphicPropertiesElement.ImageOpacity,
        StyleGraphicPropertiesElement.LineDistance,
        StyleGraphicPropertiesElement.Luminance,
        StyleGraphicPropertiesElement.MarkerEnd,
        StyleGraphicPropertiesElement.MarkerEndCenter,
        StyleGraphicPropertiesElement.MarkerEndWidth,
        StyleGraphicPropertiesElement.MarkerStart,
        StyleGraphicPropertiesElement.MarkerStartCenter,
        StyleGraphicPropertiesElement.MarkerStartWidth,
        StyleGraphicPropertiesElement.MeasureAlign,
        StyleGraphicPropertiesElement.MeasureVerticalAlign,
        StyleGraphicPropertiesElement.OleDrawAspect,
        StyleGraphicPropertiesElement.Parallel,
        StyleGraphicPropertiesElement.Placing,
        StyleGraphicPropertiesElement.Red,
        StyleGraphicPropertiesElement.ShadowColor,
        StyleGraphicPropertiesElement.ShadowOffsetX,
        StyleGraphicPropertiesElement.ShadowOffsetY,
        StyleGraphicPropertiesElement.ShadowOpacity,
        StyleGraphicPropertiesElement.ShowUnit,
        StyleGraphicPropertiesElement.StartGuide,
        StyleGraphicPropertiesElement.StartLineSpacingHorizontal,
        StyleGraphicPropertiesElement.StartLineSpacingVertical,
        StyleGraphicPropertiesElement.Stroke,
        StyleGraphicPropertiesElement.StrokeDash,
        StyleGraphicPropertiesElement.StrokeDashNames,
        StyleGraphicPropertiesElement.StrokeLinejoin,
        StyleGraphicPropertiesElement.SymbolColor,
        StyleGraphicPropertiesElement.TextareaHorizontalAlign,
        StyleGraphicPropertiesElement.TextareaVerticalAlign,
        StyleGraphicPropertiesElement.Unit,
        StyleGraphicPropertiesElement.VisibleAreaHeight,
        StyleGraphicPropertiesElement.VisibleAreaLeft,
        StyleGraphicPropertiesElement.VisibleAreaTop,
        StyleGraphicPropertiesElement.VisibleAreaWidth,
        StyleGraphicPropertiesElement.WrapInfluenceOnPosition,
        StyleGraphicPropertiesElement.BackgroundColor,
        StyleGraphicPropertiesElement.Border,
        StyleGraphicPropertiesElement.BorderBottom,
        StyleGraphicPropertiesElement.BorderLeft,
        StyleGraphicPropertiesElement.BorderRight,
        StyleGraphicPropertiesElement.BorderTop,
        StyleGraphicPropertiesElement.Clip,
        StyleGraphicPropertiesElement.Margin,
        StyleGraphicPropertiesElement.MarginBottom,
        StyleGraphicPropertiesElement.MarginLeft,
        StyleGraphicPropertiesElement.MarginRight,
        StyleGraphicPropertiesElement.MarginTop,
        StyleGraphicPropertiesElement.MaxHeight,
        StyleGraphicPropertiesElement.MaxWidth,
        StyleGraphicPropertiesElement.MinHeight,
        StyleGraphicPropertiesElement.MinWidth,
        StyleGraphicPropertiesElement.Padding,
        StyleGraphicPropertiesElement.PaddingBottom,
        StyleGraphicPropertiesElement.PaddingLeft,
        StyleGraphicPropertiesElement.PaddingRight,
        StyleGraphicPropertiesElement.PaddingTop,
        StyleGraphicPropertiesElement.WrapOption,
        StyleGraphicPropertiesElement.BorderLineWidth,
        StyleGraphicPropertiesElement.BorderLineWidthBottom,
        StyleGraphicPropertiesElement.BorderLineWidthLeft,
        StyleGraphicPropertiesElement.BorderLineWidthRight,
        StyleGraphicPropertiesElement.BorderLineWidthTop,
        StyleGraphicPropertiesElement.Editable,
        StyleGraphicPropertiesElement.FlowWithText,
        StyleGraphicPropertiesElement.HorizontalPos,
        StyleGraphicPropertiesElement.HorizontalRel,
        StyleGraphicPropertiesElement.Mirror,
        StyleGraphicPropertiesElement.NumberWrappedParagraphs,
        StyleGraphicPropertiesElement.OverflowBehavior,
        StyleGraphicPropertiesElement.PrintContent,
        StyleGraphicPropertiesElement.Protect,
        StyleGraphicPropertiesElement.RelHeight,
        StyleGraphicPropertiesElement.RelWidth,
        StyleGraphicPropertiesElement.RunThrough,
        StyleGraphicPropertiesElement.Shadow,
        StyleGraphicPropertiesElement.VerticalPos,
        StyleGraphicPropertiesElement.VerticalRel,
        StyleGraphicPropertiesElement.Wrap,
        StyleGraphicPropertiesElement.WrapContour,
        StyleGraphicPropertiesElement.WrapContourMode,
        StyleGraphicPropertiesElement.WrapDynamicThreshold,
        StyleGraphicPropertiesElement.WritingMode,
        StyleGraphicPropertiesElement.Height,
        StyleGraphicPropertiesElement.StrokeColor,
        StyleGraphicPropertiesElement.StrokeOpacity,
        StyleGraphicPropertiesElement.StrokeWidth,
        StyleGraphicPropertiesElement.Width,
        StyleGraphicPropertiesElement.X,
        StyleGraphicPropertiesElement.Y,
        StyleGraphicPropertiesElement.AnchorPageNumber,
        StyleGraphicPropertiesElement.AnchorType,
        StyleGraphicPropertiesElement.Animation,
        StyleGraphicPropertiesElement.AnimationDelay,
        StyleGraphicPropertiesElement.AnimationDirection,
        StyleGraphicPropertiesElement.AnimationRepeat,
        StyleGraphicPropertiesElement.AnimationStartInside,
        StyleGraphicPropertiesElement.AnimationSteps,
        StyleGraphicPropertiesElement.AnimationStopInside,
        StyleGraphicPropertiesElement.StrokeLinecap,
        StyleGraphicPropertiesElement.ShrinkToFit,
        StyleGraphicPropertiesElement.BackgroundTransparency,
        StyleGraphicPropertiesElement.DrawAspect,
        StyleChartPropertiesElement.ConnectBars,
        StyleChartPropertiesElement.DataLabelNumber,
        StyleChartPropertiesElement.DataLabelSymbol,
        StyleChartPropertiesElement.DataLabelText,
        StyleChartPropertiesElement.Deep,
        StyleChartPropertiesElement.DisplayLabel,
        StyleChartPropertiesElement.ErrorCategory,
        StyleChartPropertiesElement.ErrorLowerIndicator,
        StyleChartPropertiesElement.ErrorLowerLimit,
        StyleChartPropertiesElement.ErrorMargin,
        StyleChartPropertiesElement.ErrorPercentage,
        StyleChartPropertiesElement.ErrorUpperIndicator,
        StyleChartPropertiesElement.ErrorUpperLimit,
        StyleChartPropertiesElement.GapWidth,
        StyleChartPropertiesElement.Interpolation,
        StyleChartPropertiesElement.IntervalMajor,
        StyleChartPropertiesElement.IntervalMinorDivisor,
        StyleChartPropertiesElement.JapaneseCandleStick,
        StyleChartPropertiesElement.LabelArrangement,
        StyleChartPropertiesElement.Lines,
        StyleChartPropertiesElement.LinkDataStyleToSource,
        StyleChartPropertiesElement.Logarithmic,
        StyleChartPropertiesElement.Maximum,
        StyleChartPropertiesElement.MeanValue,
        StyleChartPropertiesElement.Minimum,
        StyleChartPropertiesElement.Origin,
        StyleChartPropertiesElement.Overlap,
        StyleChartPropertiesElement.Percentage,
        StyleChartPropertiesElement.PieOffset,
        StyleChartPropertiesElement.RegressionType,
        StyleChartPropertiesElement.ScaleText,
        StyleChartPropertiesElement.SeriesSource,
        StyleChartPropertiesElement.SolidType,
        StyleChartPropertiesElement.SplineOrder,
        StyleChartPropertiesElement.SplineResolution,
        StyleChartPropertiesElement.Stacked,
        StyleChartPropertiesElement.SymbolHeight,
        StyleChartPropertiesElement.SymbolType,
        StyleChartPropertiesElement.SymbolWidth,
        StyleChartPropertiesElement.TextOverlap,
        StyleChartPropertiesElement.ThreeDimensional,
        StyleChartPropertiesElement.TickMarksMajorInner,
        StyleChartPropertiesElement.TickMarksMajorOuter,
        StyleChartPropertiesElement.TickMarksMinorInner,
        StyleChartPropertiesElement.TickMarksMinorOuter,
        StyleChartPropertiesElement.Vertical,
        StyleChartPropertiesElement.Visible,
        StyleChartPropertiesElement.Direction,
        StyleChartPropertiesElement.RotationAngle,
        StyleChartPropertiesElement.LineBreak,
        StyleChartPropertiesElement.RightAngledAxes,
        StyleChartPropertiesElement.SortByXValues,
        StyleChartPropertiesElement.GroupBarsPerAxis,
        StyleChartPropertiesElement.AngleOffset,
        StyleChartPropertiesElement.HoleSize,
        StyleChartPropertiesElement.TreatEmptyCells,
        StyleChartPropertiesElement.ReverseDirection,
        StyleChartPropertiesElement.LabelPosition,
        StyleChartPropertiesElement.LabelPositionNegative,
        StyleChartPropertiesElement.AutoPosition,
        StyleChartPropertiesElement.AutoSize,
        StyleChartPropertiesElement.AxisPosition,
        StyleChartPropertiesElement.AxisLabelPosition,
        StyleChartPropertiesElement.TickMarkPosition,
        StyleChartPropertiesElement.IncludeHiddenCells
    ,
    });
    
    // todo
    public final static OdfStyleFamily List = new OdfStyleFamily("list",
//            OdfListStyle.class,
            new OdfStyleProperty[]{ 
        StyleListLevelPropertiesElement.TextAlign,
        StyleListLevelPropertiesElement.SpaceBefore,
        StyleListLevelPropertiesElement.MinLabelWidth,
        StyleListLevelPropertiesElement.MinLabelDistance,
        StyleListLevelPropertiesElement.FontName,
        StyleListLevelPropertiesElement.Width,
        StyleListLevelPropertiesElement.Height,
        StyleListLevelPropertiesElement.VerticalRel,
        StyleListLevelPropertiesElement.VerticalPos,
        StyleListLevelPropertiesElement.Y,
        StyleListLevelPropertiesElement.ListLevelPositionAndSpaceMode,
        StyleTextPropertiesElement.BackgroundColor,
        StyleTextPropertiesElement.Color,
        StyleTextPropertiesElement.Country,
        StyleTextPropertiesElement.FontFamily,
        StyleTextPropertiesElement.FontSize,
        StyleTextPropertiesElement.FontStyle,
        StyleTextPropertiesElement.FontVariant,
        StyleTextPropertiesElement.FontWeight,
        StyleTextPropertiesElement.Hyphenate,
        StyleTextPropertiesElement.HyphenationPushCharCount,
        StyleTextPropertiesElement.HyphenationRemainCharCount,
        StyleTextPropertiesElement.Language,
        StyleTextPropertiesElement.LetterSpacing,
        StyleTextPropertiesElement.TextShadow,
        StyleTextPropertiesElement.TextTransform,
        StyleTextPropertiesElement.CountryAsian,
        StyleTextPropertiesElement.CountryComplex,
        StyleTextPropertiesElement.FontCharset,
        StyleTextPropertiesElement.FontCharsetAsian,
        StyleTextPropertiesElement.FontCharsetComplex,
        StyleTextPropertiesElement.FontFamilyAsian,
        StyleTextPropertiesElement.FontFamilyComplex,
        StyleTextPropertiesElement.FontFamilyGeneric,
        StyleTextPropertiesElement.FontFamilyGenericAsian,
        StyleTextPropertiesElement.FontFamilyGenericComplex,
        StyleTextPropertiesElement.FontName,
        StyleTextPropertiesElement.FontNameAsian,
        StyleTextPropertiesElement.FontNameComplex,
        StyleTextPropertiesElement.FontPitch,
        StyleTextPropertiesElement.FontPitchAsian,
        StyleTextPropertiesElement.FontPitchComplex,
        StyleTextPropertiesElement.FontRelief,
        StyleTextPropertiesElement.FontSizeAsian,
        StyleTextPropertiesElement.FontSizeComplex,
        StyleTextPropertiesElement.FontSizeRel,
        StyleTextPropertiesElement.FontSizeRelAsian,
        StyleTextPropertiesElement.FontSizeRelComplex,
        StyleTextPropertiesElement.FontStyleAsian,
        StyleTextPropertiesElement.FontStyleComplex,
        StyleTextPropertiesElement.FontStyleName,
        StyleTextPropertiesElement.FontStyleNameAsian,
        StyleTextPropertiesElement.FontStyleNameComplex,
        StyleTextPropertiesElement.FontWeightAsian,
        StyleTextPropertiesElement.FontWeightComplex,
        StyleTextPropertiesElement.LanguageAsian,
        StyleTextPropertiesElement.LanguageComplex,
        StyleTextPropertiesElement.LetterKerning,
        StyleTextPropertiesElement.ScriptType,
        StyleTextPropertiesElement.TextBlinking,
        StyleTextPropertiesElement.TextCombine,
        StyleTextPropertiesElement.TextCombineEndChar,
        StyleTextPropertiesElement.TextCombineStartChar,
        StyleTextPropertiesElement.TextEmphasize,
        StyleTextPropertiesElement.TextLineThroughColor,
        StyleTextPropertiesElement.TextLineThroughMode,
        StyleTextPropertiesElement.TextLineThroughStyle,
        StyleTextPropertiesElement.TextLineThroughText,
        StyleTextPropertiesElement.TextLineThroughTextStyle,
        StyleTextPropertiesElement.TextLineThroughType,
        StyleTextPropertiesElement.TextLineThroughWidth,
        StyleTextPropertiesElement.TextOutline,
        StyleTextPropertiesElement.TextPosition,
        StyleTextPropertiesElement.TextRotationAngle,
        StyleTextPropertiesElement.TextRotationScale,
        StyleTextPropertiesElement.TextScale,
        StyleTextPropertiesElement.TextUnderlineColor,
        StyleTextPropertiesElement.TextUnderlineMode,
        StyleTextPropertiesElement.TextUnderlineStyle,
        StyleTextPropertiesElement.TextUnderlineType,
        StyleTextPropertiesElement.TextUnderlineWidth,
        StyleTextPropertiesElement.UseWindowFontColor,
        StyleTextPropertiesElement.Display,
        StyleTextPropertiesElement.Script,
        StyleTextPropertiesElement.ScriptAsian,
        StyleTextPropertiesElement.ScriptComplex,
        StyleTextPropertiesElement.RfcLanguageTag,
        StyleTextPropertiesElement.RfcLanguageTagAsian,
        StyleTextPropertiesElement.RfcLanguageTagComplex,
        StyleTextPropertiesElement.TextOverlineType,
        StyleTextPropertiesElement.TextOverlineStyle,
        StyleTextPropertiesElement.TextOverlineWidth,
        StyleTextPropertiesElement.TextOverlineColor,
        StyleTextPropertiesElement.TextOverlineMode
        ,
    } );
}
